mapping = {
    "ga:bounces": "bounces",
    "ga:yearMonth": "month",
    "ga:year": "year",
    "ga:date": "day",
    "ga:users": "users",
    "ga:region": "region",
    "ga:userAgeBracket": "age",
    "ga:userGender": "gender",
    "ga:sessions": "session",
    "ga:pageviews": "page_view",
    "ga:avgSessionDuration": "avg_session_duration",
    "ga:deviceCategory": "device",
    "ga:regionIsoCode": "region_iso_code",
    "ga:regionId": "region_id",
    "ga:adCost": 'ad_cost',
    "ga:impressions": "impression",
    "ga:adClicks": "click",
    "ga:adGroup": "ad_group",
    "ga:newUsers": "new_users",
    "ga:percentNewSessions": "percent_new_session",
    "ga:pagePathLevel1": "content_group",
    "ga:acquisitionTrafficChannel": "channel",
    "ga:landingPagePath": "landing",
    "ga:exitPagePath": "exit",
    "ga:channelGrouping": "channel_grouping",
    "ga:pagePath": 'page_path',
    "ga:pageTitle": 'page_title',
    "ga:country": 'country',
    "ga:isoYearIsoWeek": "week"
}
